[llvm-commits] CVS: llvm/include/llvm/Target/TargetData.h

Evan Cheng evan.cheng at apple.com
Tue Jan 23 23:04:05 PST 2007



Changes in directory llvm/include/llvm/Target:

TargetData.h updated: 1.47 -> 1.48
---
Log message:

Renamed getTypeAlignmentShift() to getPreferredTypeAlignmentShift().

---
Diffs of the changes:  (+2 -2)

 TargetData.h |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)


Index: llvm/include/llvm/Target/TargetData.h
diff -u llvm/include/llvm/Target/TargetData.h:1.47 llvm/include/llvm/Target/TargetData.h:1.48
--- llvm/include/llvm/Target/TargetData.h:1.47	Mon Jan 22 17:14:52 2007
+++ llvm/include/llvm/Target/TargetData.h	Wed Jan 24 01:03:39 2007
@@ -233,10 +233,10 @@
   /// the specified type.
   unsigned char getTypeAlignmentPref(const Type *Ty) const;
 
   /// getTypeAlignmentShift - Return the preferred alignment for the
   /// specified type, returned as log2 of the value (a shift amount).
   ///
-  unsigned char getTypeAlignmentShift(const Type *Ty) const;
+  unsigned char getPreferredTypeAlignmentShift(const Type *Ty) const;
 
   /// getIntPtrType - Return an unsigned integer type that is the same size or
   /// greater to the host pointer size.
@@ -233,10 +233,10 @@
   unsigned char getTypeAlignmentPref(const Type *Ty) const;
 
-  /// getTypeAlignmentShift - Return the preferred alignment for the
+  /// getPreferredTypeAlignmentShift - Return the preferred alignment for the
   /// specified type, returned as log2 of the value (a shift amount).
   ///






More information about the llvm-commits mailing list